Index: tests/corelib/collection_length_test.dart |
diff --git a/tests/corelib/collection_length_test.dart b/tests/corelib/collection_length_test.dart |
index 01a8061d94d02b4469783411e618a8431bf0ff93..3259ab258ae7cd737f725f9602c212e51e2e8047 100644 |
--- a/tests/corelib/collection_length_test.dart |
+++ b/tests/corelib/collection_length_test.dart |
@@ -52,12 +52,13 @@ void testList(List list, n) { |
void testLength(var lengthable, int size) { |
print(lengthable.runtimeType); // Show what hangs the test. |
int length = 0; |
// If length or isEmpty is not a constant-time (or very fast) operation, |
// this will timeout. |
for (int i = 0; i < 100000; i++) { |
if (!lengthable.isEmpty) length += lengthable.length; |
+ if (lengthable.isNotEmpty) length += lengthable.length; |
} |
- if (length != size * 100000) throw "Bad length: $length / size: $size"; |
+ if (length != size * 200000) throw "Bad length: $length / size: $size"; |
} |
@@ -52,12 +52,13 @@ void testList(List list, n) { |
print(lengthable.runtimeType); // Show what hangs the test. |
int length = 0; |
- // If length or isEmpty is not a constant-time (or very fast) operation, |
- // this will timeout. |
+ // If length, isEmpty or isNotEmpty is not a constant-time (or very fast) |
+ // operation, this will timeout. |
for (int i = 0; i < 100000; i++) { |
if (!lengthable.isEmpty) length += lengthable.length; |